@@ -43,7 +43,7 @@ static void printi2(const char *msg, const iInt2 v) {
 }
 
 static void printFixed(const iFixed x) {
-    uint32_t frac = x.comp.sign ? iFixedUnit - x.comp.frac : x.comp.frac;
+    uint32_t frac = (uint32_t)(x.comp.sign ? iFixedUnit - x.comp.frac : x.comp.frac);
     uint64_t wnum = x.comp.sign ? iFixedMaxWNum - x.comp.wnum : x.comp.wnum;
     if (frac == iFixedUnit) {
         frac = 0;
@@ -133,7 +133,11 @@ int main(int argc, char **argv) {
             printf("stored: %f %f %f %f\n", f[0], f[1], f[2], f[3]);
             print_("initv4", initv_F4(f));
         }
-        print_("zxy", zxy_F4(init_F4(1, 2, 3, 4)));
+        print_("xyz", xyz_F4(init_F4(-1, -2, -3, -4)));
+        print_("yzx", yzx_F4(init_F4(-1, -2, -3, -4)));
+        print_("zxy", zxy_F4(init_F4(-1, -2, -3, -4)));
+        print_("xzy", xzy_F4(init_F4(-1, -2, -3, -4)));
+
         iFloat4 a = init_F4(1.5, -2, 3.5, -4);
         iFloat4 b = init_F4(iRandomf(), iRandomf(), iRandomf(), 1);
         setW_F4(&b, 100.5f);
@@ -239,7 +243,7 @@ int main(int argc, char **argv) {
         /* Rotations. */
         for (int ang = 0; ang <= 360; ang += 45) {
             iMat4 rot;
-            initRotate_Mat4(&rot, init_F3(0, 1, 0), ang);
+            initRotate_Mat4(&rot, init_F3(0, 1, 0), (float)ang);
             iFloat3 rp = mulF3_Mat4(&rot, init_F3(2, 0, 0));
             print_("rotated", rp);
             printf("len: %f\n", length_F3(rp));
@@ -251,9 +255,9 @@ int main(int argc, char **argv) {
         for (int rep = 0; rep < REPS; ++rep) {
             /* Perf test. */ {
                 iMat4 rot;
-                initRotate_Mat4(&rot, init_F3(0, 1, 0), -rep);
+                initRotate_Mat4(&rot, init_F3(0, 1, 0), (float)-rep);
                 //printMat("rot", &rot);
-                res[rep] = /*printv3("rotated", */mulF3_Mat4(&rot, init_F3(0, 0, rep));
+                res[rep] = /*printv3("rotated", */mulF3_Mat4(&rot, init_F3(0, 0, (float)rep));
             }
         }
         printf("Rotation: elapsed %lf seconds\n", elapsedSeconds_Time(&start));
@@ -276,8 +280,8 @@ int main(int argc, char **argv) {
         //printv3("yuv", mulF3_Mat4(&matrix, init_F3(0, 0, 255)));
         iFloat3 color = init_F3(101, 123, 148);
         print_("original RGB", color);
-        print_("YUV", mulF3_Mat4(&matrix, color));
-        print_("back to RGB", mulF3_Mat4(&inverse, mulF3_Mat4(&matrix, color)));
+        print_("         YUV", mulF3_Mat4(&matrix, color));
+        print_(" back to RGB", mulF3_Mat4(&inverse, mulF3_Mat4(&matrix, color)));
     }
     deinit_Foundation();
 }
