@@ -37,6 +37,7 @@ extern iBlock blobLagrange_Resources;
 extern iBlock blobLicense_Resources;
 extern iBlock blobVersion_0_13_Resources;
 extern iBlock blobVersion_1_5_Resources;
+extern iBlock blobVersion_1_10_Resources;
 extern iBlock blobVersion_Resources;
 extern iBlock blobArghelp_Resources;
 extern iBlock blobCs_Resources;
@@ -45,6 +46,7 @@ extern iBlock blobEn_Resources;
 extern iBlock blobEo_Resources;
 extern iBlock blobEs_Resources;
 extern iBlock blobEs_MX_Resources;
+extern iBlock blobEu_Resources;
 extern iBlock blobFi_Resources;
 extern iBlock blobFr_Resources;
 extern iBlock blobGl_Resources;
@@ -53,9 +55,11 @@ extern iBlock blobIa_Resources;
 extern iBlock blobIe_Resources;
 extern iBlock blobIsv_Resources;
 extern iBlock blobIt_Resources;
+extern iBlock blobJa_Resources;
 extern iBlock blobNl_Resources;
 extern iBlock blobPl_Resources;
 extern iBlock blobRu_Resources;
+extern iBlock blobSgs_Resources;
 extern iBlock blobSk_Resources;
 extern iBlock blobSr_Resources;
 extern iBlock blobTok_Resources;
@@ -63,6 +67,7 @@ extern iBlock blobTr_Resources;
 extern iBlock blobUk_Resources;
 extern iBlock blobZh_Hans_Resources;
 extern iBlock blobZh_Hant_Resources;
+extern iBlock imageLogo_Resources;
 extern iBlock imageShadow_Resources;
 extern iBlock fontpackDefault_Resources;
 extern iBlock imageLagrange64_Resources;
