@@ -37,17 +37,19 @@ static iColor darkPalette_[] = {
     { 160, 160, 160, 255 },
     { 255, 255, 255, 255 },
 
-    { 106, 80,  0,   255 },
-    { 255, 192, 0,   255 },
+    { 98,  67,  7,   255 },
+    { 255, 170, 32,  255 },
     { 0,   96,  128, 255 },
     { 0,   192, 255, 255 },
-    
-    { 140, 32,  32,   255 },
-    { 255, 80, 80,  255 },
-    { 24,  80, 24,  255 },
+
+    { 140, 32,  32,  255 },
+    { 255, 80,  80,  255 },
+    { 24,  80,  24,  255 },
     { 48,  200, 48,  255 },
-    { 35,  50,  128, 255 },
-    { 92,  128,  255, 255 },
+    { 0,   70,  128, 255 },
+    { 40,  132, 255, 255 },
+    { 0,   0,   0,   0   },
+    { 0,   0,   0,   0   },
 };
 
 static iColor lightPalette_[] = {
@@ -61,13 +63,15 @@ static iColor lightPalette_[] = {
     { 235, 215, 200, 255 },
     { 10,  110, 130, 255 },
     { 170, 215, 220, 255 },
-    
-    { 150, 60,  55,   255 },
-    { 240, 180, 170,  255 },
-    { 50,   100, 50,  255 },
-    { 128,   200, 128,  255 },
-    { 80,   110,  190, 255 },
-    { 150,  192,  255, 255 },
+
+    { 150, 60,  55,  255 },
+    { 240, 180, 170, 255 },
+    { 50,  100, 50,  255 },
+    { 128, 200, 128, 255 },
+    { 50,  120, 190, 255 },
+    { 150, 211, 255, 255 },
+    { 0,   0,   0,   0   },
+    { 0,   0,   0,   0   },
 };
 
 static iColor uiPalette_[tmFirst_ColorId]; /* not theme-specific */
@@ -80,7 +84,7 @@ iLocalDef void copy_(enum iColorId dst, enum iColorId src) {
     set_Color(dst, get_Color(src));
 }
 
-static int accentColor_(enum iColorAccent accent, int brightness) {
+int color_ColorAccent(enum iColorAccent accent, iBool isBright) {
     const iBool isMedium = prefs_App()->theme == dark_ColorTheme ||
                            prefs_App()->theme == light_ColorTheme;
     const int brightColors[max_ColorAccent] = {
@@ -90,6 +94,7 @@ static int accentColor_(enum iColorAccent accent, int brightness) {
         green_ColorId,
         blue_ColorId,
         isMedium ? white_ColorId : gray75_ColorId,
+        systemHigh_ColorId,
     };
     const int darkColors[max_ColorAccent] = {
         teal_ColorId,
@@ -98,30 +103,28 @@ static int accentColor_(enum iColorAccent accent, int brightness) {
         darkGreen_ColorId,
         indigo_ColorId,
         isMedium ? black_ColorId : gray25_ColorId,
+        systemLow_ColorId,
     };
-    return brightness ? brightColors[accent] : darkColors[accent];
+    return isBright ? brightColors[accent] : darkColors[accent];
 }
 
 int accent_Color(iBool isBright) {
-    return accentColor_(prefs_App()->accent, isBright ? 1 : 0);
+    return color_ColorAccent(prefs_App()->accent, isBright);
 }
 
 void setThemePalette_Color(enum iColorTheme theme) {
     const iPrefs *prefs = prefs_App();
     memcpy(uiPalette_, isDark_ColorTheme(theme) ? darkPalette_ : lightPalette_, sizeof(darkPalette_));
-#if 0
-    if (prefs->accent == system_ColorAccent) {
-        iColor systemColor = systemAccent_Color();
-        memcpy(&uiPalette_[cyan_ColorId], &systemColor, sizeof(iColor));
-        memcpy(&uiPalette_[orange_ColorId], &systemColor, sizeof(iColor));
+    /* Update the system accent color. */ {
+        const iBool isMediumDark = prefs_App()->theme == dark_ColorTheme;
+        iColor system = systemAccent_Color();
+        darkPalette_[systemHigh_ColorId]  = system;
+        darkPalette_[systemLow_ColorId]   = rgb_HSLColor(addSatLum_HSLColor(hsl_Color(system), 0, -0.25f));
+        lightPalette_[systemHigh_ColorId] = rgb_HSLColor(addSatLum_HSLColor(hsl_Color(system), 0, 0.3f));
+        lightPalette_[systemLow_ColorId]  = rgb_HSLColor(addSatLum_HSLColor(hsl_Color(system), 0, -0.1f));
     }
-#endif
-    const int accentHi = accentColor_(prefs->accent, 1);
-    const int accentLo = accentColor_(prefs->accent, 0);
-//    const int altAccentHi = accentColor_(orange_ColorAccent, 1); //(prefs->accent == cyan_ColorAccent ? orange_ColorId : cyan_ColorId);
-//    const int altAccentLo = accentColor_(orange_ColorAccent, 0); // (prefs->accent == cyan_ColorAccent ? brown_ColorId : teal_ColorId);
-    //const iColor accentMid    = mix_Color(get_Color(accentHi), get_Color(accentLo), 0.5f);
-    //const iColor altAccentMid = mix_Color(get_Color(altAccentHi), get_Color(altAccentLo), 0.5f);
+    const int accentHi = color_ColorAccent(prefs->accent, iTrue /* bright */);
+    const int accentLo = color_ColorAccent(prefs->accent, iFalse /* dim */);
     switch (theme) {
         case pureBlack_ColorTheme: {
             copy_(uiBackground_ColorId, black_ColorId);
@@ -165,7 +168,7 @@ void setThemePalette_Color(enum iColorTheme theme) {
             copy_(uiInputCursor_ColorId, accentHi);
             copy_(uiInputCursorText_ColorId, black_ColorId);
             copy_(uiHeading_ColorId, accentHi);
-            copy_(uiAnnotation_ColorId, accentLo);
+            copy_(uiAnnotation_ColorId, accentHi);
             copy_(uiIcon_ColorId, accentHi);
             copy_(uiIconHover_ColorId, accentHi);
             copy_(uiSeparator_ColorId, gray25_ColorId);
@@ -210,7 +213,6 @@ void setThemePalette_Color(enum iColorTheme theme) {
             set_Color(uiInputBackgroundFocused_ColorId,
                       mix_Color(get_Color(black_ColorId), get_Color(gray25_ColorId), 0.82f));
             copy_(uiInputText_ColorId, gray75_ColorId);
-            //copy_(uiInputTextFocused_ColorId, white_ColorId);
             set_Color(uiInputTextFocused_ColorId, mix_Color(get_Color(white_ColorId),
                                                             get_Color(accentHi), 0.15f));
             copy_(uiInputFrame_ColorId, uiInputBackground_ColorId);
@@ -219,10 +221,10 @@ void setThemePalette_Color(enum iColorTheme theme) {
             copy_(uiInputCursor_ColorId, accentHi);
             copy_(uiInputCursorText_ColorId, black_ColorId);
             copy_(uiHeading_ColorId, accentHi);
-            copy_(uiAnnotation_ColorId, accentLo);
+            copy_(uiAnnotation_ColorId, accentHi);
             copy_(uiIcon_ColorId, accentHi);
             copy_(uiIconHover_ColorId, accentHi);
-            copy_(uiSeparator_ColorId, black_ColorId);
+            copy_(uiSeparator_ColorId, gray50_ColorId);
             copy_(uiMarked_ColorId, accentLo);
             copy_(uiMatching_ColorId, accentLo);
             break;
@@ -263,8 +265,6 @@ void setThemePalette_Color(enum iColorTheme theme) {
             copy_(uiInputBackgroundFocused_ColorId, white_ColorId);
             copy_(uiInputText_ColorId, gray25_ColorId);
             copy_(uiInputTextFocused_ColorId, black_ColorId);
-//            set_Color(uiInputFrame_ColorId,
-//                      mix_Color(get_Color(gray50_ColorId), get_Color(gray75_ColorId), 0.5f));
             copy_(uiInputFrame_ColorId, uiInputBackground_ColorId);
             copy_(uiInputFrameHover_ColorId, accentLo);
             copy_(uiInputFrameFocused_ColorId, uiInputBackgroundFocused_ColorId);
@@ -283,7 +283,6 @@ void setThemePalette_Color(enum iColorTheme theme) {
             copy_(uiBackground_ColorId, white_ColorId);
             copy_(uiBackgroundHover_ColorId, gray75_ColorId);
             copy_(uiBackgroundSelected_ColorId, accentHi);
-            //copy_(uiBackgroundPressed_ColorId, accentHi);
             set_Color(uiBackgroundPressed_ColorId,
                       mix_Color(get_Color(accentHi), get_Color(white_ColorId), 0.5f));
             copy_(uiBackgroundFramelessHover_ColorId, accentHi);
@@ -341,6 +340,10 @@ void setThemePalette_Color(enum iColorTheme theme) {
               mix_Color(get_Color(uiBackground_ColorId),
                         get_Color(uiBackgroundSelected_ColorId),
                         theme == pureBlack_ColorTheme ? 0.5f : isDark_ColorTheme(theme) ? 0.25f : 0.66f));
+    set_Color(uiBackgroundFramelessHover_ColorId,
+              mix_Color(get_Color(uiBackground_ColorId),
+                        get_Color(uiBackgroundSelected_ColorId),
+                        isDark_ColorTheme(theme) ? 0.66f : 0.375f));
     setHsl_Color(uiBackgroundFolder_ColorId,
                  addSatLum_HSLColor(get_HSLColor(uiBackgroundSidebar_ColorId),
                                     0,
@@ -358,6 +361,10 @@ void setThemePalette_Color(enum iColorTheme theme) {
         copy_(uiInputFrame_ColorId, uiBackgroundSidebar_ColorId);
         copy_(uiInputFrameFocused_ColorId, uiBackgroundSidebar_ColorId);
         copy_(uiInputBackgroundFocused_ColorId, uiBackgroundSidebar_ColorId);
+        if (theme == dark_ColorTheme || theme == light_ColorTheme) {
+            set_Color(uiSeparator_ColorId, mix_Color(get_Color(uiSeparator_ColorId),
+                                                     get_Color(uiBackgroundSidebar_ColorId), 0.5f));
+        }
     }
 }
 
@@ -369,6 +376,13 @@ iColor get_Color(int color) {
     return *rgba;
 }
 
+iColor default_Color(int color) {
+    if (color >= 0 && color < (int) iElemCount(darkPalette_)) {
+        return (isDark_ColorTheme(prefs_App()->theme) ? darkPalette_ : lightPalette_)[color];
+    }
+    return (iColor){ 0, 0, 0, 0 };
+}
+
 iColor getMixed_Color(int color1, int color2, float t) {
     return mix_Color(get_Color(color1), get_Color(color2), t);
 }
@@ -427,9 +441,32 @@ iLocalDef iColor toColor_(iFloat4 d) {
                      (uint8_t) w_F4(i) };
 }
 
+iLocalDef iColorf toColorf_(iFloat4 d) {
+    return (iColorf){ x_F4(d), y_F4(d), z_F4(d), w_F4(d) };
+}
+
+iLocalDef uint8_t quantize8_(float f) {
+    f = iClamp(f, 0.0f, 1.0f);
+    return (uint8_t) (f * 255.0f + 0.5f);
+}
+
+iColor uint8_Colorf(iColorf d) {
+    return toColor_(initv_F4(&d.r));
+}
+
+iColorf float_Color(iColor d) {
+    return (iColorf){ d.r / 255.0f, d.g / 255.0f, d.b / 255.0f, d.a / 255.0f };
+}
+
 iHSLColor hsl_Color(iColor color) {
-    float rgb[4];
-    store_F4(normalize_(color), rgb);
+    return hsl_Colorf(float_Color(color));
+}
+
+iHSLColor hsl_Colorf(iColorf color) {
+    const float rgb[4] = { iClamp(color.r, 0.0f, 1.0f),
+                           iClamp(color.g, 0.0f, 1.0f),
+                           iClamp(color.b, 0.0f, 1.0f),
+                           iClamp(color.a, 0.0f, 1.0f) };
     int compMax, compMin;
     if (rgb[0] >= rgb[1] && rgb[0] >= rgb[2]) {
         compMax = 0;
@@ -479,7 +516,7 @@ static float hueToRgb_(float p, float q, float t) {
     return p;
 }
 
-iColor rgb_HSLColor(iHSLColor hsl) {
+iColorf rgbf_HSLColor(iHSLColor hsl) {
     float r, g, b;
     hsl.hue /= 360.0f;
     hsl.hue = iWrapf(hsl.hue, 0, 1);
@@ -496,13 +533,25 @@ iColor rgb_HSLColor(iHSLColor hsl) {
         g = hueToRgb_(p, q, hsl.hue);
         b = hueToRgb_(p, q, hsl.hue - 1.0f / 3.0f);
     }
-    return toColor_(init_F4(r, g, b, hsl.a));
+    return toColorf_(init_F4(r, g, b, hsl.a));
+}
+
+iColor rgb_HSLColor(iHSLColor hsl) {
+    return uint8_Colorf(rgbf_HSLColor(hsl));
 }
 
 float luma_Color(iColor color) {
     return 0.299f * color.r / 255.0f + 0.587f * color.g / 255.0f + 0.114f * color.b / 255.0f;
 }
 
+float luma_Colorf(iColorf color) {
+    return 0.299f * color.r + 0.587f * color.g + 0.114f * color.b;
+}
+
+float luma_HSLColor(iHSLColor hsl) {
+    return luma_Color(rgb_HSLColor(hsl));
+}
+
 const char *escape_Color(int color) {
     static const char *esc[] = {
         black_ColorEscape,
@@ -829,20 +878,25 @@ static const iColor ansi8BitColors_[256] = {
     { 255, 255, 255, 255 }
 };
 
-void ansiColors_Color(iRangecc escapeSequence, int fgDefault, int bgDefault,
-                      iColor *fg_out, iColor *bg_out) {
-    if (!fg_out && !bg_out) {
+void ansiColors_Color(iRangecc escapeSequence, int fgDefault, int bgDefault, iBool isHighIntensity,
+                      iColor *fg_out, iColor *bg_out, const char **endPos_out) {
+    if (!fg_out && !bg_out && !endPos_out) {
         return;
     }
     iColor fg, bg;
     iZap(fg);
     iZap(bg);
+    if (endPos_out) {
+        *endPos_out = escapeSequence.end;
+    }
     for (const char *ch = escapeSequence.start; ch < escapeSequence.end; ch++) {
         char *endPtr;
         unsigned long arg = strtoul(ch, &endPtr, 10);
         ch = endPtr;
+        iBool isUnknown = iFalse;
         switch (arg) {
             default:
+                isUnknown = iTrue;
                 break;
             case 30:
             case 31:
@@ -852,7 +906,7 @@ void ansiColors_Color(iRangecc escapeSequence, int fgDefault, int bgDefault,
             case 35:
             case 36:
             case 37:
-                fg = ansi8BitColors_[arg - 30];
+                fg = ansi8BitColors_[arg - 30 + (isHighIntensity ? 8 : 0)];
                 break;
             case 38:
             case 48: {
@@ -884,6 +938,9 @@ void ansiColors_Color(iRangecc escapeSequence, int fgDefault, int bgDefault,
             }
             case 39:
                 fg = get_Color(fgDefault);
+                if (fg_out) {
+                    *fg_out = fg;
+                }
                 break;
             case 40:
             case 41:
@@ -893,10 +950,13 @@ void ansiColors_Color(iRangecc escapeSequence, int fgDefault, int bgDefault,
             case 45:
             case 46:
             case 47:
-                bg = ansi8BitColors_[arg - 40];
+                bg = ansi8BitColors_[arg - 40 + (isHighIntensity ? 8 : 0)];
                 break;
             case 49:
                 bg = get_Color(bgDefault);
+                if (bg_out) {
+                    *bg_out = bg;
+                }
                 break;
             case 90:
             case 91:
@@ -919,6 +979,12 @@ void ansiColors_Color(iRangecc escapeSequence, int fgDefault, int bgDefault,
                 bg = ansi8BitColors_[8 + arg - 100];
                 break;
         }
+        if (isUnknown) {
+            if (endPos_out) {
+                *endPos_out = ch;
+            }
+            break;
+        }
     }
     if (fg.a && fg_out) {
         *fg_out = fg;
@@ -960,7 +1026,7 @@ iBool loadPalette_Color(const char *path) {
                 { "black:", 0 }, { "gray25:", 1 }, { "gray50:", 2 }, { "gray75:", 3 },
                 { "white:", 4 }, { "brown:", 5 },  { "orange:", 6 }, { "teal:", 7 },
                 { "cyan:", 8 },  { "maroon:", 9 }, { "red:", 10 }, { "darkGreen:", 11 },
-                { "green:", 12 }, { "indigo:", 13 }, { "blue:", 14 }, 
+                { "green:", 12 }, { "indigo:", 13 }, { "blue:", 14 },
             };
             iForIndices(i, colors_) {
                 if (startsWithCase_Rangecc(line, colors_[i].label)) {
@@ -1004,6 +1070,6 @@ iBool loadPalette_Color(const char *path) {
 
 #if !defined (iPlatformAppleDesktop)
 iColor systemAccent_Color(void) {
-    return (iColor){ 255, 255, 255, 255 };
+    return darkPalette_[cyan_ColorId];
 }
 #endif
