@@ -26,12 +26,19 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. */
 
 #include <the_Foundation/intset.h>
 
+iDeclareType(ListWidget)
+
 enum iSidebarMode {
     bookmarks_SidebarMode,
-    feeds_SidebarMode,
-    history_SidebarMode,
+    feedEntries_SidebarMode,
+    subscriptions_SidebarMode,
     identities_SidebarMode,
     documentOutline_SidebarMode,
+    siteStructure_SidebarMode,
+    openDocuments_SidebarMode,
+    history_SidebarMode,
+    /*gempubIndex_SidebarMode,*/
+    /*customPage_SidebarMode,*/
     max_SidebarMode
 };
 
@@ -60,3 +67,5 @@ enum iSidebarMode   mode_SidebarWidget          (const iSidebarWidget *);
 enum iFeedsMode     feedsMode_SidebarWidget     (const iSidebarWidget *);
 float               width_SidebarWidget         (const iSidebarWidget *);
 const iIntSet *     closedFolders_SidebarWidget (const iSidebarWidget *);
+
+iListWidget *       list_SidebarWidget          (iSidebarWidget *);
